#!/usr/local/bin/python2.7

"""
This script will help you create the database where to store data collected by
the file integrity checker 'Spot The Difference'.

Usage:

  stdiff_install_db.py <db_type>

The only argument is the type of the database you want to create. So far, only
MySQL and PostgreSQL databases are supported by this script (SQLite and dbm
files don't need the creation of a database).
"""


import sys


################################################################################
# Constants definition                                                         #
################################################################################

usage = """
Usage:

  stdiff_install_db.py <db_type>

db_type can be either 'mysql' (MySQL database) or 'pgsql' (PostgreSQL database)
"""

# Dictionary of supported database types and modules
SUPPORTED_DB = {"mysql": "MySQLdb",
                "pgsql": "psycopg"}


################################################################################
# Main part                                                                    #
################################################################################

try:
    if sys.argv[1] not in SUPPORTED_DB.keys():
        sys.exit("\nDatabase type '%s' not supported %s" % (sys.argv[1], usage))

    # Import the specific database installation script
    exec("from spot import install_db_%s as db_installer" % sys.argv[1])

except IndexError:
    # No db type specified
    sys.exit(usage)

except ImportError:
    # Wrong db type specified
    sys.exit("\nImport failed: maybe the '%s' module is missing..." %
               SUPPORTED_DB[sys.argv[1]])

# Run the installation script
db_installer.run()

